<template>
  <j-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭">
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :labelCol="labelCol" :wrapperCol="wrapperCol" :rules="validatorRules">
        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="repairCode" label="工单编号">
              <a-input placeholder="请输入工单编号" v-model="model.repairCode"/>
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item prop="reportId" label="报修编号">
              <a-input placeholder="请输入报修编号" v-model="model.reportId"/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="equipmentId" label="设备编号">
              <lx-search-equipment-select placeholder="请输入设备编号或名称搜索" v-model="model.equipmentId"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item prop="faultReason" label="故障原因">
              <a-input placeholder="请输入故障原因" v-model="model.faultReason"/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="actualStartTime" label="维修开始时间">
              <a-input placeholder="请输入维修开始时间" v-model="model.actualStartTime"/>
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item prop="actualEndTime" label="维修结束时间">
              <a-input placeholder="请输入维修结束时间" v-model="model.actualEndTime"/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="repairDescription" label="维修结果描述">
              <a-input placeholder="请输入维修结果描述" v-model="model.repairDescription"/>
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item prop="repairer" label="维修负责人">
              <a-input placeholder="请输入维修负责人" v-model="model.repairer"/>
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="outsourcedStartTime" label="委外维修开始时间">
              <a-date-picker show-time value-format="YYYY-MM-DD HH:mm:ss" style="width: 100%"
                             placeholder="请输入委外维修开始时间"
                             v-model="model.outsourcedStartTime"/>
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item prop="outsourcedEndTime" label="委外维修结束时间">
              <a-date-picker show-time value-format="YYYY-MM-DD HH:mm:ss" style="width: 100%"
                             placeholder="请输入委外维修结束时间"
                             v-model="model.outsourcedEndTime"/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="12">
            <a-form-model-item prop="outsourcedPerson" label="委外负责人">
              <a-input placeholder="请输入委外负责人" v-model="model.outsourcedPerson"/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="24">
            <a-form-model-item prop="imageFiles" label="维修图片" :labelCol="labelColLong" :wrapperCol="wrapperColLong">
              <j-image-upload v-model="model.imageFiles" :is-multiple="true" :number="3"/>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { httpAction } from '@api/manage'
import moment from 'moment'
import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'

export default {
  name: 'EamRepairOrderModal',
  components: { LxSearchEquipmentSelect },
  data() {
    return {
      title: '操作',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 12 }
      },
      labelColLong: {
        xs: { span: 24 },
        sm: { span: 4 }
      },
      wrapperColLong: {
        xs: { span: 24 },
        sm: { span: 18 }
      },
      confirmLoading: false,
      validatorRules: {},
      url: {
        add: '/eam/eamRepairOrder/add',
        edit: '/eam/eamRepairOrder/edit'
      }
    }
  },
  created() {
  },
  methods: {
    add() {
      //初始化默认值
      this.edit({})
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },
    close() {
      this.$emit('close')
      this.visible = false
      this.$refs.form.clearValidate()
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    }


  }
}
</script>

<style lang="less" scoped>

</style>